require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_website',
  dscmeta_resource_friendly_name: 'WebSite',
  dscmeta_resource_name: 'DSC_WebSite',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'WebAdministrationDsc',
  dscmeta_module_version: '4.1.0',
  docs: 'The DSC WebSite resource type.
         Automatically generated from version 4.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_serviceautostartprovider: {
      type: 'Optional[String]',
      desc: 'Adds a AutostartProvider',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The desired name of the website.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_preloadenabled: {
      type: 'Optional[Boolean]',
      desc: 'When set to $true this will allow WebSite to automatically start without a request',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logformat: {
      type: "Optional[Enum['IIS', 'iis', 'W3C', 'w3c', 'NCSA', 'ncsa']]",
      desc: 'Format of the Logfiles. Only W3C supports LogFlags',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logperiod: {
      type: "Optional[Enum['Hourly', 'hourly', 'Daily', 'daily', 'Weekly', 'weekly', 'Monthly', 'monthly', 'MaxSize', 'maxsize']]",
      desc: 'How often the log file should rollover',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteid: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Optional. The desired IIS site Id for the website.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Ensures that the website is Present or Absent. Defaults to Present.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logtargetw3c: {
      type: "Optional[Enum['File', 'file', 'ETW', 'etw', 'File,ETW', 'file,etw']]",
      desc: 'Specifies whether IIS will use Event Tracing or file logging',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logtruncatesize: {
      type: 'Optional[String]',
      desc: 'How large the file should be before it is truncated',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceautostartenabled: {
      type: 'Optional[Boolean]',
      desc: 'When set to `$true` this will enable application Autostart (application initalization without an initial request) on a Website',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bindinginfo: {
      type: "Optional[Array[Struct[{
              sslflags => Optional[Enum['0', '1', '2', '3']],
              certificatestorename => Optional[Enum['My', 'my', 'WebHosting', 'webhosting']],
              certificatethumbprint => Optional[String],
              hostname => Optional[String],
              certificatesubject => Optional[String],
              bindinginformation => Optional[String],
              port => Optional[Integer[0, 65535]],
              ipaddress => Optional[String],
              protocol => Enum['http', 'https', 'msmq.formatname', 'net.msmq', 'net.pipe', 'net.tcp']
            }]]]",
      desc: "Website's binding information in the form of an array of embedded instances of the DSC_WebBindingInformation CIM class.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_WebBindingInformation[]',
      mof_is_embedded: true,
    },
    dsc_applicationpool: {
      type: 'Optional[String]',
      desc: 'The name of the websiteâ??s application pool.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_physicalpath: {
      type: 'Optional[String]',
      desc: 'The path to the files that compose the website.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultpage: {
      type: 'Optional[Array[String]]',
      desc: 'One or more names of files that will be set as Default Documents for this website.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_logflags: {
      type: "Optional[Array[Enum['Date', 'date', 'Time', 'time', 'ClientIP', 'clientip', 'UserName', 'username', 'SiteName', 'sitename', 'ComputerName', 'computername', 'ServerIP', 'serverip', 'Method', 'method', 'UriStem', 'uristem', 'UriQuery', 'uriquery', 'HttpStatus', 'httpstatus', 'Win32Status', 'win32status', 'BytesSent', 'bytessent', 'BytesRecv', 'bytesrecv', 'TimeTaken', 'timetaken', 'ServerPort', 'serverport', 'UserAgent', 'useragent', 'Cookie', 'cookie', 'Referer', 'referer', 'ProtocolVersion', 'protocolversion', 'Host', 'host', 'HttpSubStatus', 'httpsubstatus']]]",
      desc: 'The W3C logging fields',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applicationtype: {
      type: 'Optional[String]',
      desc: 'Adds a AutostartProvider ApplicationType',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Started', 'started', 'Stopped', 'stopped']]",
      desc: 'The state of the website.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loglocaltimerollover: {
      type: 'Optional[Boolean]',
      desc: 'Use the localtime for file naming and rollover',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_serverautostart: {
      type: 'Optional[Boolean]',
      desc: 'When set to $true this will enable Autostart on a Website',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabledprotocols: {
      type: 'Optional[String]',
      desc: 'The protocols that are enabled for the website.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: 'Optional[String]',
      desc: 'The directory to be used for logfiles',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationinfo: {
      type: 'Optional[Struct[{
              basic => Optional[Boolean],
              anonymous => Optional[Boolean],
              digest => Optional[Boolean],
              windows => Optional[Boolean]
            }]]',
      desc: 'Hashtable containing authentication information (Anonymous, Basic, Digest, Windows)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_WebAuthenticationInformation',
      mof_is_embedded: true,
    },
    dsc_logcustomfields: {
      type: "Optional[Array[Struct[{
              sourcetype => Optional[Enum['RequestHeader', 'requestheader', 'ResponseHeader', 'responseheader', 'ServerVariable', 'servervariable']],
              sourcename => Optional[String],
              logfieldname => Optional[String],
            }]]]",
      desc: 'Custom logging field information in the form of an array of embedded instances of DSC_LogCustomFieldInformation CIM class',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_LogCustomFieldInformation[]',
      mof_is_embedded: true,
    },
  },
)
